@@ -10,9 +10,11 @@
 #include <QIcon>
 #include <QIntValidator>
 #include <QScreen>
+#include <QStringBuilder>
 
 #include <KLocalizedString>
 #include <KWindowSystem>
+#include <KX11Extras>
 
 #include <ModemManagerQt/Manager>
 
@@ -130,7 +132,9 @@ PinDialog::PinDialog(ModemManager::Modem *modem, const Type type, QWidget *paren
     ui->pin->setCursorPosition(0);
     ui->pin2->setCursorPosition(0);
 
-    KWindowSystem::setState(winId(), NET::KeepAbove);
+    if (KWindowSystem::isPlatformX11()) {
+        KX11Extras::setState(winId(), NET::KeepAbove);
+    }
 
     move((desktop.width() - width()) / 2, (desktop.height() - height()) / 2);
     connect(ui->chkShowPass, &QCheckBox::toggled, this, &PinDialog::chkShowPassToggled);
@@ -253,3 +257,5 @@ bool PinDialog::isPukDialog() const
 {
     return !isPinDialog();
 }
+
+#include "moc_pindialog.cpp"
